offset_pixels

Function offset_pixels 

pub(crate) fn offset_pixels(pixmap: &mut Pixmap, dx: f32, dy: f32)
Shift all pixels in a pixmap by the given offset.

This implements the offset operation in-place by copying pixels to their new positions. The iteration order is carefully chosen based on shift direction to avoid overwriting source pixels before they’re read. Areas that become exposed (due to the shift) are filled with transparent black. Pixels that would move outside the bounds are discarded.